==> haskell-swagger2-2.2-31-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: swagger2
version: 2.2
id: swagger2-2.2-97ZfXKLinDH4OEmYXACgVn
key: swagger2-2.2-97ZfXKLinDH4OEmYXACgVn
license: BSD3
copyright: (c) 2015-2016, GetShopTV
maintainer: nickolay@getshoptv.com
homepage: https://github.com/GetShopTV/swagger2
synopsis: Swagger 2.0 data model
description:
    This library is inteded to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.
    .
    The original Swagger 2.0 specification is available at http://swagger.io/specification/.
category: Web, Swagger
author: Nickolay Kudasov
exposed: True
indefinite: False
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.ParamSchema
    Data.Swagger.Schema Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions
abi: a1594612d5142f40522240efc5d889ad
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/swagger2-2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/swagger2-2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/swagger2-2.2
hs-libraries: HSswagger2-2.2-97ZfXKLinDH4OEmYXACgVn
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    aeson-1.2.4.0-J0IgGfvF9B28Ryy7NsOCPv bytestring-0.10.8.2
    containers-0.5.10.2 hashable-1.2.6.1-A4keFPUppGkCw7JMX4jBTk
    generics-sop-0.3.2.0-DVZ1EAz7WZT3T0121HR4y2
    http-media-0.7.1.2-6chBhQkKsT63RHvpSktxOW
    insert-ordered-containers-0.2.1.0-1UwaXoZwAfU9D9HUDkhlVL
    lens-4.15.4-6hIrH4riSMC58yWO6CTtox mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT
    scientific-0.3.5.2-8Zc2VroUo3iF9E3c5Pz1Qw
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz template-haskell-2.12.0.0
    time-1.8.0.2 transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    uuid-types-1.0.3-JapvjLAqkud1SmKDqn1RFA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             aeson-1.2.4.0-J0IgGfvF9B28Ryy7NsOCPv=cb689fc7acd6290bc554164c78e4d251
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashable-1.2.6.1-A4keFPUppGkCw7JMX4jBTk=526c49aca960d0292e5723576545a03d
             generics-sop-0.3.2.0-DVZ1EAz7WZT3T0121HR4y2=d7357e208cf29ebe12d6b950c25c6a0a
             http-media-0.7.1.2-6chBhQkKsT63RHvpSktxOW=896fc86796e25743f5068c593ffe80b1
             insert-ordered-containers-0.2.1.0-1UwaXoZwAfU9D9HUDkhlVL=50ee890f9bb8a0ea6d00d2a53d20eeae
             lens-4.15.4-6hIrH4riSMC58yWO6CTtox=8fef1b158c585509e84c466e14b2e4a7
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT=3bb40bf00d3257de945a134963a298b0
             scientific-0.3.5.2-8Zc2VroUo3iF9E3c5Pz1Qw=11abcce15758b0e3fff5fe5ecd138e8b
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
             unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA=bcd116646f2dca4381cb4b7cc7ba7fb1
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             uuid-types-1.0.3-JapvjLAqkud1SmKDqn1RFA=62a3b877c4fb15cee02580bb3361e899
haddock-interfaces: /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html: /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-swagger2-2.2-35-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: swagger2
version: 2.2
id: swagger2-2.2-IYtjPTF8ofIC82OkgKGi6O
key: swagger2-2.2-IYtjPTF8ofIC82OkgKGi6O
license: BSD3
copyright: (c) 2015-2016, GetShopTV
maintainer: nickolay@getshoptv.com
homepage: https://github.com/GetShopTV/swagger2
synopsis: Swagger 2.0 data model
description:
    This library is inteded to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.
    .
    The original Swagger 2.0 specification is available at http://swagger.io/specification/.
category: Web, Swagger
author: Nickolay Kudasov
exposed: True
indefinite: False
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.ParamSchema
    Data.Swagger.Schema Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions
abi: c63930008a5d0fbb29cd0cda90d61271
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/swagger2-2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/swagger2-2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/swagger2-2.2
hs-libraries: HSswagger2-2.2-IYtjPTF8ofIC82OkgKGi6O
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    aeson-1.2.4.0-29Ui7SKICkn4HdMa5tx6LD bytestring-0.10.8.2
    containers-0.5.10.2 hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    generics-sop-0.3.2.0-DVZ1EAz7WZT3T0121HR4y2
    http-media-0.7.1.2-GtKGMDXhUAG2Nix6C3mWbv
    insert-ordered-containers-0.2.1.0-AGJV1ZPMXDKHWtvapBL1zq
    lens-4.15.4-8UeSYSjxIlc2EgNUI9WpQ1 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT
    scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz template-haskell-2.12.0.0
    time-1.8.0.2 transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    uuid-types-1.0.3-7SGDQuL1CwqDmbty1Mwily
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             aeson-1.2.4.0-29Ui7SKICkn4HdMa5tx6LD=2daf6700d9ef385ba2659a6e8aebe988
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             generics-sop-0.3.2.0-DVZ1EAz7WZT3T0121HR4y2=d7357e208cf29ebe12d6b950c25c6a0a
             http-media-0.7.1.2-GtKGMDXhUAG2Nix6C3mWbv=df53344cb10cbc12d0fac5df2d3b9fab
             insert-ordered-containers-0.2.1.0-AGJV1ZPMXDKHWtvapBL1zq=f830bf50bf66707eac67817b355cace9
             lens-4.15.4-8UeSYSjxIlc2EgNUI9WpQ1=3cb1dc030d38e8738dcf1764deccea60
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT=3bb40bf00d3257de945a134963a298b0
             scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX=7aedff29b89e83530bb1e2cdf3ff8b50
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
             unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae=b402656649e5f5df6537cabd8124c4af
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             uuid-types-1.0.3-7SGDQuL1CwqDmbty1Mwily=57ea9cee1932ecc182feef039579eb9f
haddock-interfaces: /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html: /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
